#define Py_DecRef PyPy_DecRef
#define Py_IncRef PyPy_IncRef
#define _Py_NewReference _PyPy_NewReference
#define _Py_HashPointer _PyPy_HashPointer
#define PyBool_Check PyPyBool_Check
#define PyBool_CheckExact PyPyBool_CheckExact
#define PyBool_FromLong PyPyBool_FromLong
#define PyFloat_Check PyPyFloat_Check
#define PyFloat_CheckExact PyPyFloat_CheckExact
#define PyFloat_FromDouble PyPyFloat_FromDouble
#define PyFloat_AsDouble PyPyFloat_AsDouble
#define PyFloat_AS_DOUBLE PyPyFloat_AS_DOUBLE
#define PyNumber_Float PyPyNumber_Float
#define PyFloat_FromString PyPyFloat_FromString
#define _PyFloat_Unpack4 _PyPyFloat_Unpack4
#define _PyFloat_Unpack8 _PyPyFloat_Unpack8
#define PyCFunction_Check PyPyCFunction_Check
#define PyCFunction_CheckExact PyPyCFunction_CheckExact
#define PyCFunction_NewEx PyPyCFunction_NewEx
#define PyCFunction_GetFunction PyPyCFunction_GetFunction
#define PyStaticMethod_New PyPyStaticMethod_New
#define PyClassMethod_New PyPyClassMethod_New
#define PyDescr_NewMethod PyPyDescr_NewMethod
#define PyDescr_NewClassMethod PyPyDescr_NewClassMethod
#define Py_FindMethod PyPy_FindMethod
#define PyImport_Import PyPyImport_Import
#define PyImport_ImportModule PyPyImport_ImportModule
#define PyImport_ImportModuleNoBlock PyPyImport_ImportModuleNoBlock
#define PyImport_ReloadModule PyPyImport_ReloadModule
#define PyImport_AddModule PyPyImport_AddModule
#define PyImport_GetModuleDict PyPyImport_GetModuleDict
#define PyImport_ExecCodeModule PyPyImport_ExecCodeModule
#define PyImport_ExecCodeModuleEx PyPyImport_ExecCodeModuleEx
#define PyErr_SetObject PyPyErr_SetObject
#define PyErr_SetString PyPyErr_SetString
#define PyErr_SetNone PyPyErr_SetNone
#define PyErr_Occurred PyPyErr_Occurred
#define PyErr_Clear PyPyErr_Clear
#define PyExceptionInstance_Class PyPyExceptionInstance_Class
#define PyErr_Fetch PyPyErr_Fetch
#define PyErr_Restore PyPyErr_Restore
#define PyErr_NormalizeException PyPyErr_NormalizeException
#define PyErr_BadArgument PyPyErr_BadArgument
#define PyErr_BadInternalCall PyPyErr_BadInternalCall
#define PyErr_NoMemory PyPyErr_NoMemory
#define PyErr_SetFromErrno PyPyErr_SetFromErrno
#define PyErr_SetFromErrnoWithFilename PyPyErr_SetFromErrnoWithFilename
#define PyErr_SetFromErrnoWithFilenameObject PyPyErr_SetFromErrnoWithFilenameObject
#define PyErr_CheckSignals PyPyErr_CheckSignals
#define PyErr_GivenExceptionMatches PyPyErr_GivenExceptionMatches
#define PyErr_ExceptionMatches PyPyErr_ExceptionMatches
#define PyErr_WarnEx PyPyErr_WarnEx
#define PyErr_Warn PyPyErr_Warn
#define PyErr_PrintEx PyPyErr_PrintEx
#define PyErr_Print PyPyErr_Print
#define PyErr_Display PyPyErr_Display
#define PyTraceBack_Print PyPyTraceBack_Print
#define PyErr_WriteUnraisable PyPyErr_WriteUnraisable
#define PyErr_SetInterrupt PyPyErr_SetInterrupt
#define PyErr_GetExcInfo PyPyErr_GetExcInfo
#define PyErr_SetExcInfo PyPyErr_SetExcInfo
#define _Py_InitPyPyModule _PyPy_InitPyPyModule
#define PyModule_Check PyPyModule_Check
#define PyModule_GetDict PyPyModule_GetDict
#define PyModule_GetName PyPyModule_GetName
#define Py_IsInitialized PyPy_IsInitialized
#define Py_GetProgramName PyPy_GetProgramName
#define Py_GetVersion PyPy_GetVersion
#define Py_AtExit PyPy_AtExit
#define PyInt_Check PyPyInt_Check
#define PyInt_CheckExact PyPyInt_CheckExact
#define PyInt_GetMax PyPyInt_GetMax
#define PyInt_FromLong PyPyInt_FromLong
#define PyInt_AsLong PyPyInt_AsLong
#define PyInt_AsUnsignedLong PyPyInt_AsUnsignedLong
#define PyInt_AsUnsignedLongMask PyPyInt_AsUnsignedLongMask
#define PyInt_AsUnsignedLongLongMask PyPyInt_AsUnsignedLongLongMask
#define PyInt_AS_LONG PyPyInt_AS_LONG
#define PyInt_AsSsize_t PyPyInt_AsSsize_t
#define PyInt_FromSize_t PyPyInt_FromSize_t
#define PyInt_FromSsize_t PyPyInt_FromSsize_t
#define PyInt_FromString PyPyInt_FromString
#define PyString_Check PyPyString_Check
#define PyString_CheckExact PyPyString_CheckExact
#define PyString_FromStringAndSize PyPyString_FromStringAndSize
#define PyString_FromString PyPyString_FromString
#define PyString_AsString PyPyString_AsString
#define PyString_AsStringAndSize PyPyString_AsStringAndSize
#define PyString_Size PyPyString_Size
#define _PyString_Resize _PyPyString_Resize
#define _PyString_Eq _PyPyString_Eq
#define PyString_Concat PyPyString_Concat
#define PyString_ConcatAndDel PyPyString_ConcatAndDel
#define PyString_Format PyPyString_Format
#define PyString_InternFromString PyPyString_InternFromString
#define PyString_InternInPlace PyPyString_InternInPlace
#define PyString_AsEncodedObject PyPyString_AsEncodedObject
#define PyString_AsDecodedObject PyPyString_AsDecodedObject
#define _PyString_Join _PyPyString_Join
#define PyLong_Check PyPyLong_Check
#define PyLong_CheckExact PyPyLong_CheckExact
#define PyLong_FromLong PyPyLong_FromLong
#define PyLong_FromSsize_t PyPyLong_FromSsize_t
#define PyLong_FromSize_t PyPyLong_FromSize_t
#define PyLong_FromLongLong PyPyLong_FromLongLong
#define PyLong_FromUnsignedLong PyPyLong_FromUnsignedLong
#define PyLong_FromUnsignedLongLong PyPyLong_FromUnsignedLongLong
#define PyLong_AsUnsignedLong PyPyLong_AsUnsignedLong
#define PyLong_AsUnsignedLongMask PyPyLong_AsUnsignedLongMask
#define PyLong_AsLong PyPyLong_AsLong
#define PyLong_AsSsize_t PyPyLong_AsSsize_t
#define PyLong_AsLongLong PyPyLong_AsLongLong
#define PyLong_AsUnsignedLongLong PyPyLong_AsUnsignedLongLong
#define PyLong_AsUnsignedLongLongMask PyPyLong_AsUnsignedLongLongMask
#define PyLong_AsLongAndOverflow PyPyLong_AsLongAndOverflow
#define PyLong_AsLongLongAndOverflow PyPyLong_AsLongLongAndOverflow
#define PyLong_FromDouble PyPyLong_FromDouble
#define PyLong_AsDouble PyPyLong_AsDouble
#define PyLong_FromString PyPyLong_FromString
#define PyLong_FromUnicode PyPyLong_FromUnicode
#define PyLong_FromVoidPtr PyPyLong_FromVoidPtr
#define PyLong_AsVoidPtr PyPyLong_AsVoidPtr
#define _PyLong_NumBits _PyPyLong_NumBits
#define _PyLong_Sign _PyPyLong_Sign
#define _PyLong_FromByteArray _PyPyLong_FromByteArray
#define PyMember_GetOne PyPyMember_GetOne
#define PyMember_SetOne PyPyMember_SetOne
#define PyType_Check PyPyType_Check
#define PyType_CheckExact PyPyType_CheckExact
#define PyType_Ready PyPyType_Ready
#define PyType_IsSubtype PyPyType_IsSubtype
#define PyType_GenericAlloc PyPyType_GenericAlloc
#define PyType_GenericNew PyPyType_GenericNew
#define _PyType_Lookup _PyPyType_Lookup
#define PyType_Modified PyPyType_Modified
#define PyObject_MALLOC PyPyObject_MALLOC
#define PyObject_FREE PyPyObject_FREE
#define _PyObject_New _PyPyObject_New
#define _PyObject_NewVar _PyPyObject_NewVar
#define PyObject_Del PyPyObject_Del
#define PyObject_dealloc PyPyObject_dealloc
#define _PyObject_GC_New _PyPyObject_GC_New
#define PyObject_GC_Del PyPyObject_GC_Del
#define PyObject_GC_Track PyPyObject_GC_Track
#define PyObject_GC_UnTrack PyPyObject_GC_UnTrack
#define _PyObject_GetDictPtr _PyPyObject_GetDictPtr
#define PyObject_IsTrue PyPyObject_IsTrue
#define PyObject_Not PyPyObject_Not
#define PyObject_GetAttr PyPyObject_GetAttr
#define PyObject_GetAttrString PyPyObject_GetAttrString
#define PyObject_HasAttr PyPyObject_HasAttr
#define PyObject_HasAttrString PyPyObject_HasAttrString
#define PyObject_SetAttr PyPyObject_SetAttr
#define PyObject_SetAttrString PyPyObject_SetAttrString
#define PyObject_DelAttr PyPyObject_DelAttr
#define PyObject_DelAttrString PyPyObject_DelAttrString
#define PyObject_ClearWeakRefs PyPyObject_ClearWeakRefs
#define PyObject_Size PyPyObject_Size
#define PyCallable_Check PyPyCallable_Check
#define PyObject_GetItem PyPyObject_GetItem
#define PyObject_SetItem PyPyObject_SetItem
#define PyObject_DelItem PyPyObject_DelItem
#define PyObject_Init PyPyObject_Init
#define PyObject_InitVar PyPyObject_InitVar
#define PyObject_Type PyPyObject_Type
#define PyObject_Str PyPyObject_Str
#define PyObject_Repr PyPyObject_Repr
#define PyObject_Unicode PyPyObject_Unicode
#define PyObject_Compare PyPyObject_Compare
#define PyObject_Cmp PyPyObject_Cmp
#define PyObject_RichCompare PyPyObject_RichCompare
#define PyObject_RichCompareBool PyPyObject_RichCompareBool
#define PyObject_SelfIter PyPyObject_SelfIter
#define PyObject_GenericGetAttr PyPyObject_GenericGetAttr
#define PyObject_GenericSetAttr PyPyObject_GenericSetAttr
#define PyObject_IsInstance PyPyObject_IsInstance
#define PyObject_IsSubclass PyPyObject_IsSubclass
#define PyObject_AsFileDescriptor PyPyObject_AsFileDescriptor
#define PyObject_Hash PyPyObject_Hash
#define PyObject_HashNotImplemented PyPyObject_HashNotImplemented
#define PyObject_Dir PyPyObject_Dir
#define PyObject_AsCharBuffer PyPyObject_AsCharBuffer
#define PyObject_Print PyPyObject_Print
#define PyBuffer_FillInfo PyPyBuffer_FillInfo
#define PyBuffer_Release PyPyBuffer_Release
#define PyTuple_Check PyPyTuple_Check
#define PyTuple_CheckExact PyPyTuple_CheckExact
#define PyTuple_New PyPyTuple_New
#define PyTuple_SetItem PyPyTuple_SetItem
#define PyTuple_GetItem PyPyTuple_GetItem
#define PyTuple_GET_SIZE PyPyTuple_GET_SIZE
#define PyTuple_Size PyPyTuple_Size
#define _PyTuple_Resize _PyPyTuple_Resize
#define PyTuple_GetSlice PyPyTuple_GetSlice
#define _PyArray_Check _PyPyArray_Check
#define _PyArray_CheckExact _PyPyArray_CheckExact
#define _PyArray_FLAGS _PyPyArray_FLAGS
#define _PyArray_NDIM _PyPyArray_NDIM
#define _PyArray_DIM _PyPyArray_DIM
#define _PyArray_STRIDE _PyPyArray_STRIDE
#define _PyArray_SIZE _PyPyArray_SIZE
#define _PyArray_ITEMSIZE _PyPyArray_ITEMSIZE
#define _PyArray_NBYTES _PyPyArray_NBYTES
#define _PyArray_TYPE _PyPyArray_TYPE
#define _PyArray_DATA _PyPyArray_DATA
#define _PyArray_FromAny _PyPyArray_FromAny
#define _PyArray_DescrFromType _PyPyArray_DescrFromType
#define _PyArray_FromObject _PyPyArray_FromObject
#define _PyArray_SimpleNew _PyPyArray_SimpleNew
#define _PyArray_SimpleNewFromData _PyPyArray_SimpleNewFromData
#define _PyArray_SimpleNewFromDataOwning _PyPyArray_SimpleNewFromDataOwning
#define _PyArray_New _PyPyArray_New
#define PyUFunc_FromFuncAndDataAndSignature PyPyUFunc_FromFuncAndDataAndSignature
#define PyUFunc_FromFuncAndData PyPyUFunc_FromFuncAndData
#define PySet_Check PyPySet_Check
#define PySet_CheckExact PyPySet_CheckExact
#define PySet_New PyPySet_New
#define PySet_Add PyPySet_Add
#define PySet_Discard PyPySet_Discard
#define PySet_Pop PyPySet_Pop
#define PySet_Clear PyPySet_Clear
#define PySet_GET_SIZE PyPySet_GET_SIZE
#define PySet_Size PyPySet_Size
#define PySet_Contains PyPySet_Contains
#define PyDict_New PyPyDict_New
#define PyDict_Check PyPyDict_Check
#define PyDict_CheckExact PyPyDict_CheckExact
#define PyDict_GetItem PyPyDict_GetItem
#define PyDict_SetItem PyPyDict_SetItem
#define PyDict_DelItem PyPyDict_DelItem
#define PyDict_SetItemString PyPyDict_SetItemString
#define PyDict_GetItemString PyPyDict_GetItemString
#define PyDict_DelItemString PyPyDict_DelItemString
#define PyDict_Size PyPyDict_Size
#define PyDict_Contains PyPyDict_Contains
#define PyDict_Clear PyPyDict_Clear
#define PyDict_Copy PyPyDict_Copy
#define PyDict_Update PyPyDict_Update
#define PyDict_Keys PyPyDict_Keys
#define PyDict_Values PyPyDict_Values
#define PyDict_Items PyPyDict_Items
#define PyDict_Next PyPyDict_Next
#define PyDictProxy_New PyPyDictProxy_New
#define PyList_Check PyPyList_Check
#define PyList_CheckExact PyPyList_CheckExact
#define PyList_New PyPyList_New
#define PyList_SetItem PyPyList_SetItem
#define PyList_GetItem PyPyList_GetItem
#define PyList_Append PyPyList_Append
#define PyList_Insert PyPyList_Insert
#define PyList_GET_SIZE PyPyList_GET_SIZE
#define PyList_Size PyPyList_Size
#define PyList_AsTuple PyPyList_AsTuple
#define PyList_Sort PyPyList_Sort
#define PyList_Reverse PyPyList_Reverse
#define PyList_GetSlice PyPyList_GetSlice
#define PyList_SetSlice PyPyList_SetSlice
#define PySequence_Repeat PyPySequence_Repeat
#define PySequence_Check PyPySequence_Check
#define PySequence_Size PyPySequence_Size
#define PySequence_Length PyPySequence_Length
#define PySequence_Fast PyPySequence_Fast
#define PySequence_Fast_GET_ITEM PyPySequence_Fast_GET_ITEM
#define PySequence_Fast_GET_SIZE PyPySequence_Fast_GET_SIZE
#define PySequence_GetSlice PyPySequence_GetSlice
#define PySequence_SetSlice PyPySequence_SetSlice
#define PySequence_DelSlice PyPySequence_DelSlice
#define PySequence_ITEM PyPySequence_ITEM
#define PySequence_GetItem PyPySequence_GetItem
#define PySequence_List PyPySequence_List
#define PySequence_Tuple PyPySequence_Tuple
#define PySequence_Concat PyPySequence_Concat
#define PySequence_Contains PyPySequence_Contains
#define PySeqIter_New PyPySeqIter_New
#define PySequence_SetItem PyPySequence_SetItem
#define PySequence_DelItem PyPySequence_DelItem
#define PySequence_Index PyPySequence_Index
#define PyObject_CheckBuffer PyPyObject_CheckBuffer
#define PyObject_GetBuffer PyPyObject_GetBuffer
#define PyBuffer_IsContiguous PyPyBuffer_IsContiguous
#define PyFunction_Check PyPyFunction_Check
#define PyFunction_CheckExact PyPyFunction_CheckExact
#define PyMethod_Check PyPyMethod_Check
#define PyMethod_CheckExact PyPyMethod_CheckExact
#define PyCode_Check PyPyCode_Check
#define PyCode_CheckExact PyPyCode_CheckExact
#define PyFunction_GetCode PyPyFunction_GetCode
#define PyMethod_New PyPyMethod_New
#define PyMethod_Function PyPyMethod_Function
#define PyMethod_Self PyPyMethod_Self
#define PyMethod_Class PyPyMethod_Class
#define PyCode_New PyPyCode_New
#define PyCode_NewEmpty PyPyCode_NewEmpty
#define PyCode_GetNumFree PyPyCode_GetNumFree
#define PyEval_CallObjectWithKeywords PyPyEval_CallObjectWithKeywords
#define PyEval_GetBuiltins PyPyEval_GetBuiltins
#define PyEval_GetLocals PyPyEval_GetLocals
#define PyEval_GetGlobals PyPyEval_GetGlobals
#define PyEval_EvalCode PyPyEval_EvalCode
#define PyObject_CallObject PyPyObject_CallObject
#define PyObject_Call PyPyObject_Call
#define PyRun_SimpleString PyPyRun_SimpleString
#define PyRun_String PyPyRun_String
#define PyRun_StringFlags PyPyRun_StringFlags
#define PyRun_File PyPyRun_File
#define _PyEval_SliceIndex _PyPyEval_SliceIndex
#define Py_CompileStringFlags PyPy_CompileStringFlags
#define PyEval_MergeCompilerFlags PyPyEval_MergeCompilerFlags
#define PyMapping_Check PyPyMapping_Check
#define PyMapping_Size PyPyMapping_Size
#define PyMapping_Length PyPyMapping_Length
#define PyMapping_Keys PyPyMapping_Keys
#define PyMapping_Values PyPyMapping_Values
#define PyMapping_Items PyPyMapping_Items
#define PyMapping_GetItemString PyPyMapping_GetItemString
#define PyMapping_SetItemString PyPyMapping_SetItemString
#define PyMapping_HasKey PyPyMapping_HasKey
#define PyMapping_HasKeyString PyPyMapping_HasKeyString
#define PyCallIter_New PyPyCallIter_New
#define PyObject_GetIter PyPyObject_GetIter
#define PyIter_Next PyPyIter_Next
#define PyIter_Check PyPyIter_Check
#define PyUnicode_Check PyPyUnicode_Check
#define PyUnicode_CheckExact PyPyUnicode_CheckExact
#define Py_UNICODE_ISSPACE PyPy_UNICODE_ISSPACE
#define Py_UNICODE_ISALPHA PyPy_UNICODE_ISALPHA
#define Py_UNICODE_ISALNUM PyPy_UNICODE_ISALNUM
#define Py_UNICODE_ISLINEBREAK PyPy_UNICODE_ISLINEBREAK
#define Py_UNICODE_ISDECIMAL PyPy_UNICODE_ISDECIMAL
#define Py_UNICODE_ISDIGIT PyPy_UNICODE_ISDIGIT
#define Py_UNICODE_ISNUMERIC PyPy_UNICODE_ISNUMERIC
#define Py_UNICODE_ISLOWER PyPy_UNICODE_ISLOWER
#define Py_UNICODE_ISUPPER PyPy_UNICODE_ISUPPER
#define Py_UNICODE_ISTITLE PyPy_UNICODE_ISTITLE
#define Py_UNICODE_TOLOWER PyPy_UNICODE_TOLOWER
#define Py_UNICODE_TOUPPER PyPy_UNICODE_TOUPPER
#define Py_UNICODE_TOTITLE PyPy_UNICODE_TOTITLE
#define Py_UNICODE_TODECIMAL PyPy_UNICODE_TODECIMAL
#define Py_UNICODE_TODIGIT PyPy_UNICODE_TODIGIT
#define Py_UNICODE_TONUMERIC PyPy_UNICODE_TONUMERIC
#define PyUnicode_GetMax PyPyUnicode_GetMax
#define PyUnicode_AS_DATA PyPyUnicode_AS_DATA
#define PyUnicode_GET_DATA_SIZE PyPyUnicode_GET_DATA_SIZE
#define PyUnicode_GET_SIZE PyPyUnicode_GET_SIZE
#define PyUnicode_AS_UNICODE PyPyUnicode_AS_UNICODE
#define PyUnicode_AsUnicode PyPyUnicode_AsUnicode
#define PyUnicode_GetSize PyPyUnicode_GetSize
#define PyUnicode_AsWideChar PyPyUnicode_AsWideChar
#define PyUnicode_GetDefaultEncoding PyPyUnicode_GetDefaultEncoding
#define PyUnicode_SetDefaultEncoding PyPyUnicode_SetDefaultEncoding
#define PyUnicode_AsEncodedObject PyPyUnicode_AsEncodedObject
#define PyUnicode_AsEncodedString PyPyUnicode_AsEncodedString
#define PyUnicode_AsUnicodeEscapeString PyPyUnicode_AsUnicodeEscapeString
#define PyUnicode_FromUnicode PyPyUnicode_FromUnicode
#define PyUnicode_FromWideChar PyPyUnicode_FromWideChar
#define _PyUnicode_AsDefaultEncodedString _PyPyUnicode_AsDefaultEncodedString
#define PyUnicode_Decode PyPyUnicode_Decode
#define PyUnicode_FromObject PyPyUnicode_FromObject
#define PyUnicode_FromEncodedObject PyPyUnicode_FromEncodedObject
#define PyUnicode_FromString PyPyUnicode_FromString
#define PyUnicode_FromStringAndSize PyPyUnicode_FromStringAndSize
#define PyUnicode_FromOrdinal PyPyUnicode_FromOrdinal
#define PyUnicode_Resize PyPyUnicode_Resize
#define PyUnicode_AsUTF8String PyPyUnicode_AsUTF8String
#define PyUnicode_DecodeUTF8 PyPyUnicode_DecodeUTF8
#define PyUnicode_EncodeUTF8 PyPyUnicode_EncodeUTF8
#define PyUnicode_AsASCIIString PyPyUnicode_AsASCIIString
#define PyUnicode_DecodeASCII PyPyUnicode_DecodeASCII
#define PyUnicode_EncodeASCII PyPyUnicode_EncodeASCII
#define PyUnicode_AsLatin1String PyPyUnicode_AsLatin1String
#define PyUnicode_DecodeLatin1 PyPyUnicode_DecodeLatin1
#define PyUnicode_EncodeLatin1 PyPyUnicode_EncodeLatin1
#define PyUnicode_DecodeUTF16 PyPyUnicode_DecodeUTF16
#define PyUnicode_DecodeUTF32 PyPyUnicode_DecodeUTF32
#define PyUnicode_EncodeDecimal PyPyUnicode_EncodeDecimal
#define PyUnicode_Compare PyPyUnicode_Compare
#define Py_UNICODE_COPY PyPy_UNICODE_COPY
#define PyUnicode_Format PyPyUnicode_Format
#define PyUnicode_Join PyPyUnicode_Join
#define PyUnicode_Replace PyPyUnicode_Replace
#define PyUnicode_Tailmatch PyPyUnicode_Tailmatch
#define PyUnicode_Count PyPyUnicode_Count
#define PyUnicode_Find PyPyUnicode_Find
#define PyUnicode_Split PyPyUnicode_Split
#define PyUnicode_Splitlines PyPyUnicode_Splitlines
#define PySys_GetObject PyPySys_GetObject
#define PySys_SetObject PyPySys_SetObject
#define PyIndex_Check PyPyIndex_Check
#define PyNumber_Check PyPyNumber_Check
#define PyNumber_AsSsize_t PyPyNumber_AsSsize_t
#define PyNumber_Int PyPyNumber_Int
#define PyNumber_Long PyPyNumber_Long
#define PyNumber_Index PyPyNumber_Index
#define PyNumber_CoerceEx PyPyNumber_CoerceEx
#define PyNumber_Coerce PyPyNumber_Coerce
#define PyNumber_Add PyPyNumber_Add
#define PyNumber_InPlaceAdd PyPyNumber_InPlaceAdd
#define PyNumber_Subtract PyPyNumber_Subtract
#define PyNumber_InPlaceSubtract PyPyNumber_InPlaceSubtract
#define PyNumber_Multiply PyPyNumber_Multiply
#define PyNumber_InPlaceMultiply PyPyNumber_InPlaceMultiply
#define PyNumber_Divide PyPyNumber_Divide
#define PyNumber_InPlaceDivide PyPyNumber_InPlaceDivide
#define PyNumber_FloorDivide PyPyNumber_FloorDivide
#define PyNumber_InPlaceFloorDivide PyPyNumber_InPlaceFloorDivide
#define PyNumber_TrueDivide PyPyNumber_TrueDivide
#define PyNumber_InPlaceTrueDivide PyPyNumber_InPlaceTrueDivide
#define PyNumber_Remainder PyPyNumber_Remainder
#define PyNumber_InPlaceRemainder PyPyNumber_InPlaceRemainder
#define PyNumber_Lshift PyPyNumber_Lshift
#define PyNumber_InPlaceLshift PyPyNumber_InPlaceLshift
#define PyNumber_Rshift PyPyNumber_Rshift
#define PyNumber_InPlaceRshift PyPyNumber_InPlaceRshift
#define PyNumber_And PyPyNumber_And
#define PyNumber_InPlaceAnd PyPyNumber_InPlaceAnd
#define PyNumber_Xor PyPyNumber_Xor
#define PyNumber_InPlaceXor PyPyNumber_InPlaceXor
#define PyNumber_Or PyPyNumber_Or
#define PyNumber_InPlaceOr PyPyNumber_InPlaceOr
#define PyNumber_Divmod PyPyNumber_Divmod
#define PyNumber_Negative PyPyNumber_Negative
#define PyNumber_Positive PyPyNumber_Positive
#define PyNumber_Absolute PyPyNumber_Absolute
#define PyNumber_Invert PyPyNumber_Invert
#define PyNumber_Power PyPyNumber_Power
#define PyNumber_InPlacePower PyPyNumber_InPlacePower
#define PySlice_Check PyPySlice_Check
#define PySlice_CheckExact PyPySlice_CheckExact
#define PySlice_New PyPySlice_New
#define PySlice_GetIndicesEx PyPySlice_GetIndicesEx
#define PySlice_GetIndices PyPySlice_GetIndices
#define PyEval_SaveThread PyPyEval_SaveThread
#define PyEval_RestoreThread PyPyEval_RestoreThread
#define PyEval_InitThreads PyPyEval_InitThreads
#define PyEval_ThreadsInitialized PyPyEval_ThreadsInitialized
#define PyThreadState_Get PyPyThreadState_Get
#define PyThreadState_GetDict PyPyThreadState_GetDict
#define PyThreadState_Swap PyPyThreadState_Swap
#define PyEval_AcquireThread PyPyEval_AcquireThread
#define PyEval_ReleaseThread PyPyEval_ReleaseThread
#define PyGILState_Ensure PyPyGILState_Ensure
#define PyGILState_Release PyPyGILState_Release
#define PyInterpreterState_Head PyPyInterpreterState_Head
#define PyInterpreterState_Next PyPyInterpreterState_Next
#define PyThreadState_New PyPyThreadState_New
#define PyThreadState_Clear PyPyThreadState_Clear
#define PyThreadState_Delete PyPyThreadState_Delete
#define PyThreadState_DeleteCurrent PyPyThreadState_DeleteCurrent
#define PyFile_AsFile PyPyFile_AsFile
#define Py_MakePendingCalls PyPy_MakePendingCalls
#define Py_AddPendingCall PyPy_AddPendingCall
#define PyThread_start_new_thread PyPyThread_start_new_thread
#define _PyDateTime_Import _PyPyDateTime_Import
#define PyDateTime_Check PyPyDateTime_Check
#define PyDateTime_CheckExact PyPyDateTime_CheckExact
#define PyDate_Check PyPyDate_Check
#define PyDate_CheckExact PyPyDate_CheckExact
#define PyTime_Check PyPyTime_Check
#define PyTime_CheckExact PyPyTime_CheckExact
#define PyDelta_Check PyPyDelta_Check
#define PyDelta_CheckExact PyPyDelta_CheckExact
#define PyDate_FromDate PyPyDate_FromDate
#define PyTime_FromTime PyPyTime_FromTime
#define PyDateTime_FromDateAndTime PyPyDateTime_FromDateAndTime
#define PyDateTime_FromTimestamp PyPyDateTime_FromTimestamp
#define PyDate_FromTimestamp PyPyDate_FromTimestamp
#define PyDelta_FromDSU PyPyDelta_FromDSU
#define PyDateTime_GET_YEAR PyPyDateTime_GET_YEAR
#define PyDateTime_GET_MONTH PyPyDateTime_GET_MONTH
#define PyDateTime_GET_DAY PyPyDateTime_GET_DAY
#define PyDateTime_DATE_GET_HOUR PyPyDateTime_DATE_GET_HOUR
#define PyDateTime_DATE_GET_MINUTE PyPyDateTime_DATE_GET_MINUTE
#define PyDateTime_DATE_GET_SECOND PyPyDateTime_DATE_GET_SECOND
#define PyDateTime_DATE_GET_MICROSECOND PyPyDateTime_DATE_GET_MICROSECOND
#define PyDateTime_TIME_GET_HOUR PyPyDateTime_TIME_GET_HOUR
#define PyDateTime_TIME_GET_MINUTE PyPyDateTime_TIME_GET_MINUTE
#define PyDateTime_TIME_GET_SECOND PyPyDateTime_TIME_GET_SECOND
#define PyDateTime_TIME_GET_MICROSECOND PyPyDateTime_TIME_GET_MICROSECOND
#define PyDateTime_DELTA_GET_DAYS PyPyDateTime_DELTA_GET_DAYS
#define PyDateTime_DELTA_GET_SECONDS PyPyDateTime_DELTA_GET_SECONDS
#define PyDateTime_DELTA_GET_MICROSECONDS PyPyDateTime_DELTA_GET_MICROSECONDS
#define PyComplex_Check PyPyComplex_Check
#define PyComplex_CheckExact PyPyComplex_CheckExact
#define PyComplex_FromDoubles PyPyComplex_FromDoubles
#define PyComplex_RealAsDouble PyPyComplex_RealAsDouble
#define PyComplex_ImagAsDouble PyPyComplex_ImagAsDouble
#define _PyComplex_FromCComplex _PyPyComplex_FromCComplex
#define _PyComplex_AsCComplex _PyPyComplex_AsCComplex
#define PyWeakref_NewRef PyPyWeakref_NewRef
#define PyWeakref_NewProxy PyPyWeakref_NewProxy
#define PyWeakref_GetObject PyPyWeakref_GetObject
#define PyWeakref_GET_OBJECT PyPyWeakref_GET_OBJECT
#define PyWeakref_LockObject PyPyWeakref_LockObject
#define PyFrame_New PyPyFrame_New
#define PyTraceBack_Here PyPyTraceBack_Here
#define PyTraceBack_Check PyPyTraceBack_Check
#define PyClass_Check PyPyClass_Check
#define PyClass_CheckExact PyPyClass_CheckExact
#define PyInstance_Check PyPyInstance_Check
#define PyInstance_CheckExact PyPyInstance_CheckExact
#define PyInstance_NewRaw PyPyInstance_NewRaw
#define PyInstance_New PyPyInstance_New
#define _PyInstance_Lookup _PyPyInstance_Lookup
#define PyClass_New PyPyClass_New
#define PyPy_Borrow PyPyPy_Borrow
#define PyMemoryView_FromObject PyPyMemoryView_FromObject
#define PyCodec_IncrementalEncoder PyPyCodec_IncrementalEncoder
#define PyCodec_IncrementalDecoder PyPyCodec_IncrementalDecoder
#define PyFile_Check PyPyFile_Check
#define PyFile_CheckExact PyPyFile_CheckExact
#define PyFile_GetLine PyPyFile_GetLine
#define PyFile_FromString PyPyFile_FromString
#define PyFile_FromFile PyPyFile_FromFile
#define PyFile_SetBufSize PyPyFile_SetBufSize
#define PyFile_WriteString PyPyFile_WriteString
#define PyFile_WriteObject PyPyFile_WriteObject
#define PyFile_Name PyPyFile_Name
#define PyFile_SoftSpace PyPyFile_SoftSpace
#define PyOS_string_to_double PyPyOS_string_to_double
#define PyOS_double_to_string PyPyOS_double_to_string
#define Py_FatalError PyPy_FatalError
#define PyOS_snprintf PyPyOS_snprintf
#define PyOS_vsnprintf PyPyOS_vsnprintf
#define PyArg_Parse PyPyArg_Parse
#define PyArg_ParseTuple PyPyArg_ParseTuple
#define PyArg_UnpackTuple PyPyArg_UnpackTuple
#define PyArg_ParseTupleAndKeywords PyPyArg_ParseTupleAndKeywords
#define PyArg_VaParse PyPyArg_VaParse
#define PyArg_VaParseTupleAndKeywords PyPyArg_VaParseTupleAndKeywords
#define _PyArg_NoKeywords _PyPyArg_NoKeywords
#define PyString_FromFormat PyPyString_FromFormat
#define PyString_FromFormatV PyPyString_FromFormatV
#define PyModule_AddObject PyPyModule_AddObject
#define PyModule_AddIntConstant PyPyModule_AddIntConstant
#define PyModule_AddStringConstant PyPyModule_AddStringConstant
#define Py_BuildValue PyPy_BuildValue
#define Py_VaBuildValue PyPy_VaBuildValue
#define PyTuple_Pack PyPyTuple_Pack
#define _PyArg_Parse_SizeT _PyPyArg_Parse_SizeT
#define _PyArg_ParseTuple_SizeT _PyPyArg_ParseTuple_SizeT
#define _PyArg_ParseTupleAndKeywords_SizeT _PyPyArg_ParseTupleAndKeywords_SizeT
#define _PyArg_VaParse_SizeT _PyPyArg_VaParse_SizeT
#define _PyArg_VaParseTupleAndKeywords_SizeT _PyPyArg_VaParseTupleAndKeywords_SizeT
#define _Py_BuildValue_SizeT _PyPy_BuildValue_SizeT
#define _Py_VaBuildValue_SizeT _PyPy_VaBuildValue_SizeT
#define PyErr_Format PyPyErr_Format
#define PyErr_NewException PyPyErr_NewException
#define PyErr_NewExceptionWithDoc PyPyErr_NewExceptionWithDoc
#define PySys_WriteStdout PyPySys_WriteStdout
#define PySys_WriteStderr PyPySys_WriteStderr
#define PyEval_CallFunction PyPyEval_CallFunction
#define PyEval_CallMethod PyPyEval_CallMethod
#define PyObject_CallFunction PyPyObject_CallFunction
#define PyObject_CallMethod PyPyObject_CallMethod
#define PyObject_CallFunctionObjArgs PyPyObject_CallFunctionObjArgs
#define PyObject_CallMethodObjArgs PyPyObject_CallMethodObjArgs
#define _PyObject_CallFunction_SizeT _PyPyObject_CallFunction_SizeT
#define _PyObject_CallMethod_SizeT _PyPyObject_CallMethod_SizeT
#define PyBuffer_FromMemory PyPyBuffer_FromMemory
#define PyBuffer_FromReadWriteMemory PyPyBuffer_FromReadWriteMemory
#define PyBuffer_FromObject PyPyBuffer_FromObject
#define PyBuffer_FromReadWriteObject PyPyBuffer_FromReadWriteObject
#define PyBuffer_New PyPyBuffer_New
#define PyBuffer_Type PyPyBuffer_Type
#define _Py_get_buffer_type _PyPy_get_buffer_type
#define PyCObject_FromVoidPtr PyPyCObject_FromVoidPtr
#define PyCObject_FromVoidPtrAndDesc PyPyCObject_FromVoidPtrAndDesc
#define PyCObject_AsVoidPtr PyPyCObject_AsVoidPtr
#define PyCObject_GetDesc PyPyCObject_GetDesc
#define PyCObject_Import PyPyCObject_Import
#define PyCObject_SetVoidPtr PyPyCObject_SetVoidPtr
#define PyCObject_Type PyPyCObject_Type
#define _Py_get_cobject_type _PyPy_get_cobject_type
#define PyCapsule_New PyPyCapsule_New
#define PyCapsule_IsValid PyPyCapsule_IsValid
#define PyCapsule_GetPointer PyPyCapsule_GetPointer
#define PyCapsule_GetName PyPyCapsule_GetName
#define PyCapsule_GetDestructor PyPyCapsule_GetDestructor
#define PyCapsule_GetContext PyPyCapsule_GetContext
#define PyCapsule_SetPointer PyPyCapsule_SetPointer
#define PyCapsule_SetName PyPyCapsule_SetName
#define PyCapsule_SetDestructor PyPyCapsule_SetDestructor
#define PyCapsule_SetContext PyPyCapsule_SetContext
#define PyCapsule_Import PyPyCapsule_Import
#define PyCapsule_Type PyPyCapsule_Type
#define _Py_get_capsule_type _PyPy_get_capsule_type
#define PyObject_AsReadBuffer PyPyObject_AsReadBuffer
#define PyObject_AsWriteBuffer PyPyObject_AsWriteBuffer
#define PyObject_CheckReadBuffer PyPyObject_CheckReadBuffer
#define PyOS_getsig PyPyOS_getsig
#define PyOS_setsig PyPyOS_setsig
#define PyThread_get_thread_ident PyPyThread_get_thread_ident
#define PyThread_allocate_lock PyPyThread_allocate_lock
#define PyThread_free_lock PyPyThread_free_lock
#define PyThread_acquire_lock PyPyThread_acquire_lock
#define PyThread_release_lock PyPyThread_release_lock
#define PyThread_create_key PyPyThread_create_key
#define PyThread_delete_key PyPyThread_delete_key
#define PyThread_set_key_value PyPyThread_set_key_value
#define PyThread_get_key_value PyPyThread_get_key_value
#define PyThread_delete_key_value PyPyThread_delete_key_value
#define PyThread_ReInitTLS PyPyThread_ReInitTLS
#define PyStructSequence_InitType PyPyStructSequence_InitType
#define PyStructSequence_New PyPyStructSequence_New
#define PyStructSequence_UnnamedField PyPyStructSequence_UnnamedField
#define PyFunction_Type PyPyFunction_Type
#define PyMethod_Type PyPyMethod_Type
#define PyRange_Type PyPyRange_Type
#define PyTraceBack_Type PyPyTraceBack_Type
#define PyArray_Type PyPyArray_Type
#define _PyArray_FILLWBYTE _PyPyArray_FILLWBYTE
#define _PyArray_ZEROS _PyPyArray_ZEROS
#define _PyArray_CopyInto _PyPyArray_CopyInto
#define Py_DebugFlag PyPy_DebugFlag
#define Py_VerboseFlag PyPy_VerboseFlag
#define Py_InteractiveFlag PyPy_InteractiveFlag
#define Py_InspectFlag PyPy_InspectFlag
#define Py_OptimizeFlag PyPy_OptimizeFlag
#define Py_NoSiteFlag PyPy_NoSiteFlag
#define Py_BytesWarningFlag PyPy_BytesWarningFlag
#define Py_UseClassExceptionsFlag PyPy_UseClassExceptionsFlag
#define Py_FrozenFlag PyPy_FrozenFlag
#define Py_TabcheckFlag PyPy_TabcheckFlag
#define Py_UnicodeFlag PyPy_UnicodeFlag
#define Py_IgnoreEnvironmentFlag PyPy_IgnoreEnvironmentFlag
#define Py_DivisionWarningFlag PyPy_DivisionWarningFlag
#define Py_DontWriteBytecodeFlag PyPy_DontWriteBytecodeFlag
#define Py_NoUserSiteDirectory PyPy_NoUserSiteDirectory
#define _Py_QnewFlag _PyPy_QnewFlag
#define Py_Py3kWarningFlag PyPy_Py3kWarningFlag
#define Py_HashRandomizationFlag PyPy_HashRandomizationFlag
#define _Py_PackageContext _PyPy_PackageContext
#define _Py_NoneStruct _PyPy_NoneStruct
#define _Py_TrueStruct _PyPy_TrueStruct
#define _Py_ZeroStruct _PyPy_ZeroStruct
#define _Py_NotImplementedStruct _PyPy_NotImplementedStruct
#define _Py_EllipsisObject _PyPy_EllipsisObject
#define PyDateTimeAPI PyPyDateTimeAPI
#define PyExc_ArithmeticError PyPyExc_ArithmeticError
#define _PyExc_ArithmeticError _PyPyExc_ArithmeticError
#define PyExc_AssertionError PyPyExc_AssertionError
#define _PyExc_AssertionError _PyPyExc_AssertionError
#define PyExc_AttributeError PyPyExc_AttributeError
#define _PyExc_AttributeError _PyPyExc_AttributeError
#define PyExc_BaseException PyPyExc_BaseException
#define _PyExc_BaseException _PyPyExc_BaseException
#define PyExc_BufferError PyPyExc_BufferError
#define _PyExc_BufferError _PyPyExc_BufferError
#define PyExc_BytesWarning PyPyExc_BytesWarning
#define _PyExc_BytesWarning _PyPyExc_BytesWarning
#define PyExc_DeprecationWarning PyPyExc_DeprecationWarning
#define _PyExc_DeprecationWarning _PyPyExc_DeprecationWarning
#define PyExc_EOFError PyPyExc_EOFError
#define _PyExc_EOFError _PyPyExc_EOFError
#define PyExc_EnvironmentError PyPyExc_EnvironmentError
#define _PyExc_EnvironmentError _PyPyExc_EnvironmentError
#define PyExc_Exception PyPyExc_Exception
#define _PyExc_Exception _PyPyExc_Exception
#define PyExc_FloatingPointError PyPyExc_FloatingPointError
#define _PyExc_FloatingPointError _PyPyExc_FloatingPointError
#define PyExc_FutureWarning PyPyExc_FutureWarning
#define _PyExc_FutureWarning _PyPyExc_FutureWarning
#define PyExc_GeneratorExit PyPyExc_GeneratorExit
#define _PyExc_GeneratorExit _PyPyExc_GeneratorExit
#define PyExc_IOError PyPyExc_IOError
#define _PyExc_IOError _PyPyExc_IOError
#define PyExc_ImportError PyPyExc_ImportError
#define _PyExc_ImportError _PyPyExc_ImportError
#define PyExc_ImportWarning PyPyExc_ImportWarning
#define _PyExc_ImportWarning _PyPyExc_ImportWarning
#define PyExc_IndentationError PyPyExc_IndentationError
#define _PyExc_IndentationError _PyPyExc_IndentationError
#define PyExc_IndexError PyPyExc_IndexError
#define _PyExc_IndexError _PyPyExc_IndexError
#define PyExc_KeyError PyPyExc_KeyError
#define _PyExc_KeyError _PyPyExc_KeyError
#define PyExc_KeyboardInterrupt PyPyExc_KeyboardInterrupt
#define _PyExc_KeyboardInterrupt _PyPyExc_KeyboardInterrupt
#define PyExc_LookupError PyPyExc_LookupError
#define _PyExc_LookupError _PyPyExc_LookupError
#define PyExc_MemoryError PyPyExc_MemoryError
#define _PyExc_MemoryError _PyPyExc_MemoryError
#define PyExc_NameError PyPyExc_NameError
#define _PyExc_NameError _PyPyExc_NameError
#define PyExc_NotImplementedError PyPyExc_NotImplementedError
#define _PyExc_NotImplementedError _PyPyExc_NotImplementedError
#define PyExc_OSError PyPyExc_OSError
#define _PyExc_OSError _PyPyExc_OSError
#define PyExc_OverflowError PyPyExc_OverflowError
#define _PyExc_OverflowError _PyPyExc_OverflowError
#define PyExc_PendingDeprecationWarning PyPyExc_PendingDeprecationWarning
#define _PyExc_PendingDeprecationWarning _PyPyExc_PendingDeprecationWarning
#define PyExc_ReferenceError PyPyExc_ReferenceError
#define _PyExc_ReferenceError _PyPyExc_ReferenceError
#define PyExc_RuntimeError PyPyExc_RuntimeError
#define _PyExc_RuntimeError _PyPyExc_RuntimeError
#define PyExc_RuntimeWarning PyPyExc_RuntimeWarning
#define _PyExc_RuntimeWarning _PyPyExc_RuntimeWarning
#define PyExc_StandardError PyPyExc_StandardError
#define _PyExc_StandardError _PyPyExc_StandardError
#define PyExc_StopIteration PyPyExc_StopIteration
#define _PyExc_StopIteration _PyPyExc_StopIteration
#define PyExc_SyntaxError PyPyExc_SyntaxError
#define _PyExc_SyntaxError _PyPyExc_SyntaxError
#define PyExc_SyntaxWarning PyPyExc_SyntaxWarning
#define _PyExc_SyntaxWarning _PyPyExc_SyntaxWarning
#define PyExc_SystemExit PyPyExc_SystemExit
#define _PyExc_SystemExit _PyPyExc_SystemExit
#define PyExc_SystemError PyPyExc_SystemError
#define _PyExc_SystemError _PyPyExc_SystemError
#define PyExc_TabError PyPyExc_TabError
#define _PyExc_TabError _PyPyExc_TabError
#define PyExc_TypeError PyPyExc_TypeError
#define _PyExc_TypeError _PyPyExc_TypeError
#define PyExc_UnboundLocalError PyPyExc_UnboundLocalError
#define _PyExc_UnboundLocalError _PyPyExc_UnboundLocalError
#define PyExc_UnicodeDecodeError PyPyExc_UnicodeDecodeError
#define _PyExc_UnicodeDecodeError _PyPyExc_UnicodeDecodeError
#define PyExc_UnicodeEncodeError PyPyExc_UnicodeEncodeError
#define _PyExc_UnicodeEncodeError _PyPyExc_UnicodeEncodeError
#define PyExc_UnicodeError PyPyExc_UnicodeError
#define _PyExc_UnicodeError _PyPyExc_UnicodeError
#define PyExc_UnicodeTranslateError PyPyExc_UnicodeTranslateError
#define _PyExc_UnicodeTranslateError _PyPyExc_UnicodeTranslateError
#define PyExc_UnicodeWarning PyPyExc_UnicodeWarning
#define _PyExc_UnicodeWarning _PyPyExc_UnicodeWarning
#define PyExc_UserWarning PyPyExc_UserWarning
#define _PyExc_UserWarning _PyPyExc_UserWarning
#define PyExc_ValueError PyPyExc_ValueError
#define _PyExc_ValueError _PyPyExc_ValueError
#define PyExc_Warning PyPyExc_Warning
#define _PyExc_Warning _PyPyExc_Warning
#define PyExc_ZeroDivisionError PyPyExc_ZeroDivisionError
#define _PyExc_ZeroDivisionError _PyPyExc_ZeroDivisionError
#define PyType_Type PyPyType_Type
#define PyString_Type PyPyString_Type
#define PyUnicode_Type PyPyUnicode_Type
#define PyBaseString_Type PyPyBaseString_Type
#define PyDict_Type PyPyDict_Type
#define PyTuple_Type PyPyTuple_Type
#define PyList_Type PyPyList_Type
#define PySet_Type PyPySet_Type
#define PyFrozenSet_Type PyPyFrozenSet_Type
#define PyInt_Type PyPyInt_Type
#define PyBool_Type PyPyBool_Type
#define PyFloat_Type PyPyFloat_Type
#define PyLong_Type PyPyLong_Type
#define PyComplex_Type PyPyComplex_Type
#define PyByteArray_Type PyPyByteArray_Type
#define PyMemoryView_Type PyPyMemoryView_Type
#define PyArray_Type PyPyArray_Type
#define PyBaseObject_Type PyPyBaseObject_Type
#define PyNone_Type PyPyNone_Type
#define PyNotImplemented_Type PyPyNotImplemented_Type
#define PyCell_Type PyPyCell_Type
#define PyModule_Type PyPyModule_Type
#define PyProperty_Type PyPyProperty_Type
#define PySlice_Type PyPySlice_Type
#define PyClass_Type PyPyClass_Type
#define PyStaticMethod_Type PyPyStaticMethod_Type
#define PyCFunction_Type PyPyCFunction_Type
#define PyWrapperDescr_Type PyPyWrapperDescr_Type
#define SIZEOF_LONG_LONG 8
#define SIZEOF_VOID_P 8
#define SIZEOF_SIZE_T 8
#define SIZEOF_TIME_T 8
#define SIZEOF_LONG 8
#define SIZEOF_SHORT 2
#define SIZEOF_INT 4
#define SIZEOF_FLOAT 4
#define SIZEOF_DOUBLE 8
